==> startrek-0.2.11.tar.gz: startrek-0.2.11/startrek/fsm/__init__.py <==
# -*- coding: utf-8 -*-
#
#   Finite State Machine
#
#                                Written in 2021 by Moky <albert.moky@gmail.com>
#
# ==============================================================================
# MIT License
#
# Copyright (c) 2021 Albert Moky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ==============================================================================

"""
    Finite State Machine
    ~~~~~~~~~~~~~~~~~~~~
"""

from .runner import Ticker, Processor, Handler, Runnable, Runner
from .machine import Context, Transition, State, Machine, Delegate as StateDelegate
from .base import BaseTransition, BaseState, BaseMachine
from .auto import AutoMachine

name = "FSM"

__author__ = 'Albert Moky'

__all__ = [
    'Ticker', 'Processor', 'Handler', 'Runnable', 'Runner',
    'Context', 'Transition', 'State', 'Machine', 'StateDelegate',
    'BaseTransition', 'BaseState', 'BaseMachine',
    'AutoMachine',
]

==> startrek-0.3.4.tar.gz: startrek-0.3.4/startrek/fsm/__init__.py <==
# -*- coding: utf-8 -*-
#
#   Finite State Machine
#
#                                Written in 2021 by Moky <albert.moky@gmail.com>
#
# ==============================================================================
# MIT License
#
# Copyright (c) 2021 Albert Moky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ==============================================================================

"""
    Finite State Machine
    ~~~~~~~~~~~~~~~~~~~~
"""

from .runner import Ticker, Processor, Handler, Runnable, Runner, Daemon
from .machine import Context, Transition, State, Machine, Delegate as StateDelegate
from .base import BaseTransition, BaseState, BaseMachine
from .auto import AutoMachine

name = "FSM"

__author__ = 'Albert Moky'

__all__ = [
    'Ticker', 'Processor', 'Handler', 'Runnable', 'Runner', 'Daemon',
    'Context', 'Transition', 'State', 'Machine', 'StateDelegate',
    'BaseTransition', 'BaseState', 'BaseMachine',
    'AutoMachine',
]
